import uuid

from django.http import HttpResponse
from django.shortcuts import render
from django.utils import timezone

from .models import Thought


def index(request):
    authenticated = False
    try:
        if request.COOKIES["password"] == "ChromaticWave":
            authenticated = True
    except KeyError:
        pass

    try:
        highlighted_uuid = uuid.UUID(request.GET.get("show", ""))
    except ValueError:
        highlighted_uuid = ""

    thoughts = Thought.objects.order_by("-posted")

    for thought in thoughts:
        thought.timezone = timezone.get_fixed_timezone(-thought.timezone_offset)
        offset_hours = -thought.timezone_offset / 60
        if offset_hours == int(offset_hours):
            offset_hours = int(offset_hours)
        if offset_hours > 0:
            offset_hours = "+" + str(offset_hours)
        thought.offset_hours = offset_hours

    return render(request, "whispermaphone/index.html", {
        "thoughts": thoughts,
        "highlighted": highlighted_uuid,
        "authenticated": authenticated
    })


def post(request):
    try:
        if not request.COOKIES["password"] == "ChromaticWave":
            return render(request, "whispermaphone/login.html", status=401)
    except KeyError:
        return render(request, "whispermaphone/login.html", status=401)

    if request.method == "POST":
        if len(request.POST["text"].strip()) == 0:
            return HttpResponse("Need some text.", status=400)

        if len(request.POST["text"]) > 140:
            return HttpResponse("Content too long", status=400)

        Thought(
            text=request.POST["text"],
            extended_text=request.POST["extended_text"],
            timezone_offset=request.POST["timezone_offset"]
        ).save()

    return render(request, "whispermaphone/post.html", {})
